@@ -49,9 +49,6 @@
 #ifdef HAVE_NSSWITCH_H
 #include <nsswitch.h>
 #endif /* HAVE_NSSWITCH_H */
-#ifdef HAVE_IRS_NSS_H
-#include "irs-nss.h"
-#endif /* HAVE_IRS_NSS_H */
 
 #include "compat/ether.h"
 
@@ -110,7 +107,7 @@ struct etherent {
 #endif /* not HAVE_STRUCT_ETHERENT */
 
 /* We also define struct __netgrent because its definition is
-   not publically available. This is taken from inet/netgroup.h
+   not publicly available. This is taken from inet/netgroup.h
    of the glibc (2.3.6) source tarball.
    The first part of the struct is the only part that is modified
    by our getnetgrent() function, all the other fields are not
